import lodash from 'lodash'
import { interact } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    person: [],
    visitingDaily: [],
    visitingLog: [],
  },
  mutations: {
    updateStat (state, payload) {
      Object.keys(payload).forEach((k) => {
        const val = payload[k]
        state[k] = Array.isArray(val) ? [ ...val ] : { ...val }
      })
    },
  },
  actions: {
    getPersonStats ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'stats.person')
        interact(api, payload).then((data) => {
          commit('updateStat', { person :data })
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    
    getVisitingDaily ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'stats.daily.visiting')
        interact(api, payload).then((data) => {
          commit('updateStat', { visitingDaily :data })
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    
    getVisitingLog ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'visitinglog.list')
        interact(api, payload).then((data) => {
          commit('updateStat', { visitingLog :data })
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
  }
}
